@@ -3,8 +3,11 @@ Main interface for resource-groups service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.resource_groups import (
+
+    from mypy_boto3_resource_groups import ResourceGroupsClient
+    from mypy_boto3_resource_groups import (
         ListGroupResourcesPaginator,
         ListGroupsPaginator,
         SearchResourcesPaginator,
@@ -15,6 +18,7 @@ Usage::
     list_group_resources_paginator: ListGroupResourcesPaginator = client.get_paginator("list_group_resources")
     list_groups_paginator: ListGroupsPaginator = client.get_paginator("list_groups")
     search_resources_paginator: SearchResourcesPaginator = client.get_paginator("search_resources")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, List, TYPE_CHECKING
@@ -35,7 +39,7 @@ __all__ = ("ListGroupResourcesPaginator", "ListGroupsPaginator", "SearchResource
 
 class ListGroupResourcesPaginator(Boto3Paginator):
     """
-    [Paginator.ListGroupResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)
+    [Paginator.ListGroupResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)
     """
 
     def paginate(
@@ -45,13 +49,13 @@ class ListGroupResourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListGroupResourcesOutputTypeDef]:
         """
-        [ListGroupResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources.paginate)
+        [ListGroupResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources.paginate)
         """
 
 
 class ListGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)
+    [Paginator.ListGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)
     """
 
     def paginate(
@@ -60,18 +64,18 @@ class ListGroupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListGroupsOutputTypeDef]:
         """
-        [ListGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups.paginate)
+        [ListGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups.paginate)
         """
 
 
 class SearchResourcesPaginator(Boto3Paginator):
     """
-    [Paginator.SearchResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
+    [Paginator.SearchResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
     """
 
     def paginate(
-        self, ResourceQuery: ResourceQueryTypeDef, PaginationConfig: PaginatorConfigTypeDef = None
+        self, ResourceQuery: "ResourceQueryTypeDef", PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[SearchResourcesOutputTypeDef]:
         """
-        [SearchResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources.paginate)
+        [SearchResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources.paginate)
         """
